SystemOrganization addCategory: #'Irka-Core'!
SystemOrganization addCategory: #'Irka-GUI'!
SystemOrganization addCategory: #'Irka-Test'!

StandardWindow subclass: #IrkaBrowser
	instanceVariableNames: 'servers chans users messagePanels messageContainer'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Irka-GUI'!

!IrkaBrowser methodsFor: 'private' stamp: 'AttilaMagyar 9/23/2012 20:03'!
createLeftRightPane
	^ Morph new
		layoutPolicy: RowLayout new;
		listDirection: #leftToRight;
		hResizing: #spaceFill;
		vResizing: #spaceFill;			
		cellInset: 1;
		layoutInset: 1;
		color: Color transparent;
		yourself! !

!IrkaBrowser methodsFor: 'private' stamp: 'AttilaMagyar 9/23/2012 20:39'!
createListBox: anIrkaListModel
	| scrollPane listBox |
	scrollPane := ScrollPane new.
	listBox := (PluggableListMorph 
				on: anIrkaListModel list: #list selected: #index changeSelected: #index: menu: #menu)
				hResizing: #spaceFill; 
				vResizing: #spaceFill;
				yourself.
	scrollPane addMorph: listBox.
	^ listBox.! !

!IrkaBrowser methodsFor: 'private' stamp: 'AttilaMagyar 9/23/2012 20:12'!
createTopBottomPane
	^ Morph new
		layoutPolicy: TableLayout new;	
		listDirection: #topToBottom;
		hResizing: #spaceFill;
		vResizing: #spaceFill;		
		cellInset: 1;
		layoutInset: 1;		
		color: Color transparent;
		yourself.! !

!IrkaBrowser methodsFor: 'initialization' stamp: 'AttilaMagyar 9/24/2012 23:45'!
initWindow
	| contentPane browserPane controlPane serverList chanList userList |
	self title: 'Irka browser'.
	messageContainer := Morph new color: Color green; hResizing: #spaceFill; vResizing: #spaceFill; yourself.
	contentPane := self createTopBottomPane.	
	browserPane := self createLeftRightPane.
	controlPane := self createLeftRightPane.	
	servers := IrkaListModel new.
	servers add: 'irc.freenode.net'. "TODO" 
	chans := IrkaListModel new.
	users := IrkaListModel new.	
	serverList := self createListBox: servers.
	chanList := self createListBox: chans.
	userList := self createListBox: users.
	browserPane
		addMorph: userList;		
		addMorph: chanList;
		addMorph: serverList.
		
		messageContainer addMorph: IrkaMessagesMorph new.
	contentPane addMorph: messageContainer;
					addMorph: browserPane.
	self addMorph: contentPane frame: (0@0 corner: 1@01).! !

!IrkaBrowser methodsFor: 'initialization' stamp: 'AttilaMagyar 9/24/2012 22:55'!
initialize
	super initialize.
	self initWindow.
	messagePanels := Dictionary new.! !

!IrkaBrowser methodsFor: 'events' stamp: 'AttilaMagyar 9/24/2012 23:35'!
joinedTo: anIrkaJoined
	| messagesMorph |
	"TODO only if nick = me"
	messagesMorph := IrkaMessagesMorph new.
	messagePanels at: anIrkaJoined chan put: messagesMorph.
	
	WorldState addDeferredUIMessage: [ 
		messageContainer removeAllMorphs.
		messageContainer addMorph: messagesMorph ].
	
	chans add: anIrkaJoined chan.
	anIrkaJoined chan announcer on: IrkaMessage send: #messageReceived: to: self.! !

!IrkaBrowser methodsFor: 'events' stamp: 'AttilaMagyar 9/24/2012 23:20'!
messageReceived: anIrkaMessage
	| messagesMorph |
	messagesMorph := messagePanels at: anIrkaMessage chan.
	messagesMorph addMessage: ('[', anIrkaMessage user ,']>> ', anIrkaMessage message).
	
	users clean. "TODO"
	anIrkaMessage chan users do: [:each | users add: each ].! !

BabyMockTestCase subclass: #IrkaChannelTest
	instanceVariableNames: 'chan translator'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Irka-Test'!

!IrkaChannelTest methodsFor: 'running' stamp: 'AttilaMagyar 9/23/2012 19:03'!
setUp
	translator := context mock: 'translator'.
	chan := IrkaChannel named: '#mychan' translator: translator.
	context visualize: chan.! !

!IrkaChannelTest methodsFor: 'tests' stamp: 'AttilaMagyar 9/23/2012 19:23'!
testThatItCanBeLeft
	translator should receive: #translateLeave:; with: '#mychan'.
	chan leave.! !

!IrkaChannelTest methodsFor: 'tests' stamp: 'AttilaMagyar 9/23/2012 19:03'!
testThatItCanSendMessagesToTheChan
	translator should receive: #translateMessage:to:; with: 'msg 1 2' and: '#mychan'.
	chan message: 'msg 1 2'.! !

BabyMockTestCase subclass: #IrkaSessionTest
	instanceVariableNames: 'session translator me'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Irka-Test'!

!IrkaSessionTest methodsFor: 'matchers' stamp: 'AttilaMagyar 9/16/2012 00:12'!
chan: anIrkaChannel hasUsers: anArray 
	^ anIrkaChannel users = (OrderedCollection newFrom: anArray).! !

!IrkaSessionTest methodsFor: 'private' stamp: 'AttilaMagyar 9/22/2012 23:52'!
joined: chanName
	| joinedChan |
	session announcer on: IrkaJoined do: [:act | joinedChan := act chan ].
	session translated: (IrkaTranslated joined: me to: chanName).
	^ joinedChan! !

!IrkaSessionTest methodsFor: 'running' stamp: 'AttilaMagyar 9/17/2012 20:12'!
setUp
	me := 'mynick'.
	session := IrkaSession forUser: me.
	translator := context mock: 'translator'.
	session translator: translator.
	context visualize: session.! !

!IrkaSessionTest methodsFor: 'tests' stamp: 'AttilaMagyar 9/23/2012 18:50'!
testThatItCanChangeNick
	translator should receive: #translateChangeNick:; with: 'newnick'.
	session changeNick: 'newnick'.
! !

!IrkaSessionTest methodsFor: 'tests' stamp: 'AttilaMagyar 9/22/2012 23:48'!
testThatItCanJoinToChan
	translator should receive: #translateJoin:; with: '#chan'.
	session joinChan: '#chan'.
! !

!IrkaSessionTest methodsFor: 'tests' stamp: 'AttilaMagyar 9/23/2012 18:46'!
testThatItCanQuit
	translator should receive: #translateQuit.
	session quit.
! !

!IrkaSessionTest methodsFor: 'tests' stamp: 'AttilaMagyar 9/22/2012 23:45'!
testThatItForwardsIncomingMessageToChan
	| chanListener chan |		
	chanListener := context mock: 'chanListener'.	
	chanListener should receive: #msg:; with: [ :its | its message = 'msg 1 2' & its chan == chan & its user = 'nick' ].																
	chan := self joined: '#chan'.
	chan announcer on: IrkaMessage send: #msg: to: chanListener.
	self user: 'nick' said: 'msg 1 2' on: '#chan'.! !

!IrkaSessionTest methodsFor: 'tests' stamp: 'AttilaMagyar 9/23/2012 00:47'!
testThatItRecordsJoinedUsersInChannels
	| chan1 chan2 |			
	chan1 := self joined: '#chan1'.
	chan2 := self joined: '#chan2'.			
	self user: 'nick' joinedTo: '#chan1'.
	self assert: (self chan: chan1 hasUsers: {me. 'nick'}).
	self assert: (self chan: chan2 hasUsers: {me}).! !

!IrkaSessionTest methodsFor: 'tests' stamp: 'AttilaMagyar 9/23/2012 00:51'!
testThatItRecordsUsersAfterNickListReceived
	| chan |
	chan := self joined: '#chan'.
	session translated: (IrkaTranslated nickList: #(nick1 nick2) on: '#chan').
	self assert: (self chan: chan hasUsers: {'nick1'. 'nick2'}). ! !

!IrkaSessionTest methodsFor: 'tests' stamp: 'AttilaMagyar 9/17/2012 20:11'!
testThatItRegistersItself
	translator should receive: #translateRegisterUser:; with: me.
	session register.
! !

!IrkaSessionTest methodsFor: 'private' stamp: 'AttilaMagyar 9/22/2012 22:49'!
user: nick joinedTo: chan
	session translated: (IrkaTranslated joined: nick to: chan)! !

!IrkaSessionTest methodsFor: 'private' stamp: 'AttilaMagyar 9/22/2012 22:49'!
user: nick said: msg on: chan
	session translated: (IrkaTranslated message: msg fromNick: nick toChan: chan).! !

BabyMockTestCase subclass: #IrkaTranslatorTest
	instanceVariableNames: 'translator connection'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Irka-Test'!

!IrkaTranslatorTest methodsFor: 'running' stamp: 'AttilaMagyar 9/23/2012 01:02'!
setUp
	translator := IrkaIrcTranslator new.
	connection := context mock: 'connection'.
	translator connection: connection.
	context visualize: translator.! !

!IrkaTranslatorTest methodsFor: 'tests translate message to irc' stamp: 'AttilaMagyar 9/22/2012 20:10'!
testThatItTranslatesJoinMessage
	connection should receive: #send:; with: 'JOIN #chan'.
	translator translateJoin: '#chan'.! !

!IrkaTranslatorTest methodsFor: 'tests translate message to irc' stamp: 'AttilaMagyar 9/23/2012 19:24'!
testThatItTranslatesLeave
	connection should receive: #send:; with: 'PART #chan'.
	translator translateLeave: '#chan'.! !

!IrkaTranslatorTest methodsFor: 'tests translate message to irc' stamp: 'AttilaMagyar 9/23/2012 19:07'!
testThatItTranslatesMessage
	connection should receive: #send:; with: 'PRIVMSG #chan :msg 1 2'.
	translator translateMessage: 'msg 1 2' to: '#chan'.! !

!IrkaTranslatorTest methodsFor: 'tests translate irc to message' stamp: 'AttilaMagyar 9/23/2012 00:37'!
testThatItTranslatesNameListCommand
	| listener |
	listener := context mock: 'listener'.
	listener should receive: #namelist:; with: [:its | its chanName = '#chan' & its nicks = #(mynick othernick) ].
	translator announcer on: IrkaTranslatedNameList send: #namelist: to: listener.
	translator translateRaw: (RawLineReceived parse: ':server 353 mynick = #chan :mynick othernick').! !

!IrkaTranslatorTest methodsFor: 'tests translate message to irc' stamp: 'AttilaMagyar 9/23/2012 18:47'!
testThatItTranslatesQuit
	connection should receive: #send:; with: 'QUIT'.
	connection should receive: #disconnect.
	translator translateQuit.! !

!IrkaTranslatorTest methodsFor: 'tests translate irc to message' stamp: 'AttilaMagyar 9/22/2012 23:53'!
testThatItTranslatesRawJoin
	| listener |
	listener := context mock: 'listener'.
	listener should receive: #joinChan:; with: [:it| it nick = 'nick!!host' & it chanName = '#chan' ].
	translator announcer on: IrkaTranslatedJoin send: #joinChan: to: listener.
	translator translateRaw: (RawLineReceived parse: 'nick!!host JOIN #chan').! !

!IrkaTranslatorTest methodsFor: 'tests translate irc to message' stamp: 'AttilaMagyar 9/22/2012 23:53'!
testThatItTranslatesRawPrivMsg
	| listener |
	listener := context mock: 'listener'.
	listener should receive: #msg:; with: [:it| it nick = 'nick!!host' & it chanName = '#chan' & it message = 'msg 1 2' ].
	translator announcer on: IrkaTranslatedChanMsg send: #msg: to: listener.
	translator translateRaw: (RawLineReceived parse: 'nick!!host PRIVMSG #chan :msg 1 2').! !

!IrkaTranslatorTest methodsFor: 'tests translate message to irc' stamp: 'AttilaMagyar 9/17/2012 21:05'!
testThatItTranslatesRegisterMessage
	connection should receive: #send:; with: 'NICK nick'.
	connection should receive: #send:; with: 'USER nick Server 0 :nick'.	
	translator translateRegisterUser: 'nick'.! !

Announcement subclass: #IrkaAction
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Irka-Core'!

!IrkaAction class methodsFor: 'instance creation' stamp: 'AttilaMagyar 9/22/2012 23:01'!
message: message on: chan from: user
	^ IrkaMessage new message: message on: chan from: user! !

IrkaAction subclass: #IrkaJoined
	instanceVariableNames: 'chan user'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Irka-Core'!

!IrkaJoined class methodsFor: 'instance creation' stamp: 'AttilaMagyar 9/22/2012 20:24'!
user: aUser to: aChan
	^ self new user: aUser chan: aChan! !

!IrkaJoined methodsFor: 'as yet unclassified' stamp: 'AttilaMagyar 9/22/2012 20:23'!
chan
	^ chan! !

!IrkaJoined methodsFor: 'as yet unclassified' stamp: 'AttilaMagyar 9/22/2012 20:26'!
user: aUser chan: aChan
	user := aUser.
	chan := aChan.! !

IrkaAction subclass: #IrkaMessage
	instanceVariableNames: 'chan user message'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Irka-Core'!

!IrkaMessage methodsFor: 'accessing' stamp: 'AttilaMagyar 9/22/2012 23:04'!
chan
	^ chan! !

!IrkaMessage methodsFor: 'accessing' stamp: 'AttilaMagyar 9/22/2012 23:04'!
message
	^ message! !

!IrkaMessage methodsFor: 'initialize-release' stamp: 'AttilaMagyar 9/22/2012 23:03'!
message: aMessage on: anIrkaChannel from: anIrkaUser
	message := aMessage.
	chan := anIrkaChannel.
	user := anIrkaUser.! !

!IrkaMessage methodsFor: 'accessing' stamp: 'AttilaMagyar 9/22/2012 23:04'!
user
	^ user! !

Announcement subclass: #IrkaTranslated
	instanceVariableNames: 'nick chanName'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Irka-Core'!

!IrkaTranslated class methodsFor: 'instance creation' stamp: 'AttilaMagyar 9/22/2012 23:56'!
joined: nick to: chanName
	^ IrkaTranslatedJoin new nick: nick; chanName: chanName; yourself! !

!IrkaTranslated class methodsFor: 'instance creation' stamp: 'AttilaMagyar 9/22/2012 23:56'!
message: msg fromNick: nick toChan: chanName
	^ IrkaTranslatedChanMsg new nick: nick; chanName: chanName; message: msg; yourself.! !

!IrkaTranslated class methodsFor: 'instance creation' stamp: 'AttilaMagyar 9/23/2012 00:14'!
nickList: anArray on: chanName
	^ IrkaTranslatedNameList new nicks: anArray; chanName: chanName; yourself.! !

!IrkaTranslated methodsFor: 'accessing' stamp: 'AttilaMagyar 9/22/2012 23:57'!
chanName
	^ chanName! !

!IrkaTranslated methodsFor: 'accessing' stamp: 'AttilaMagyar 9/22/2012 23:57'!
chanName: aByteSymbol 
	chanName := aByteSymbol.! !

!IrkaTranslated methodsFor: 'accessing' stamp: 'AttilaMagyar 9/15/2012 23:09'!
nick
	^ nick! !

!IrkaTranslated methodsFor: 'accessing' stamp: 'AttilaMagyar 9/15/2012 22:52'!
nick: aByteString 
	nick := aByteString ! !

IrkaTranslated subclass: #IrkaTranslatedChanMsg
	instanceVariableNames: 'message'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Irka-Core'!

!IrkaTranslatedChanMsg methodsFor: 'accessing' stamp: 'AttilaMagyar 9/17/2012 20:08'!
message
	^ message! !

!IrkaTranslatedChanMsg methodsFor: 'accessing' stamp: 'AttilaMagyar 9/16/2012 12:36'!
message: aByteString 
	message := aByteString ! !

!IrkaTranslatedChanMsg methodsFor: 'questions' stamp: 'AttilaMagyar 9/16/2012 12:39'!
whatHappened: questioner
	questioner chanMessageReceived: self.! !

IrkaTranslated subclass: #IrkaTranslatedJoin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Irka-Core'!

!IrkaTranslatedJoin methodsFor: 'questions' stamp: 'AttilaMagyar 9/15/2012 23:08'!
whatHappened: questioner
	questioner joined: self! !

IrkaTranslated subclass: #IrkaTranslatedLeave
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Irka-Core'!

IrkaTranslated subclass: #IrkaTranslatedNameList
	instanceVariableNames: 'nicks'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Irka-Core'!

!IrkaTranslatedNameList methodsFor: 'accessing' stamp: 'AttilaMagyar 9/23/2012 00:33'!
nicks
	^ nicks! !

!IrkaTranslatedNameList methodsFor: 'accessing' stamp: 'AttilaMagyar 9/23/2012 00:15'!
nicks: anArray
	nicks := anArray ! !

!IrkaTranslatedNameList methodsFor: 'as yet unclassified' stamp: 'AttilaMagyar 9/23/2012 00:46'!
whatHappened: questioner
	questioner nickListReceived: nicks on: chanName! !

Announcement subclass: #RawLineReceived
	instanceVariableNames: 'sender command args'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Irka-Core'!

!RawLineReceived class methodsFor: 'instance creation' stamp: 'AttilaMagyar 9/17/2012 20:47'!
parse: line
	| args command tokens sender |
	args := line findTokens: ' '.
	tokens := args removeFirst: 2.
	sender := tokens at: 1.
	command := tokens at: 2.
	args := ' ' join: args.
	^ self new sender: sender; command: command; args: args; yourself.! !

!RawLineReceived methodsFor: 'initialize-release' stamp: 'AttilaMagyar 9/17/2012 20:51'!
args
	^ args! !

!RawLineReceived methodsFor: 'initialize-release' stamp: 'AttilaMagyar 9/17/2012 20:48'!
args: anArray
	args := anArray ! !

!RawLineReceived methodsFor: 'initialize-release' stamp: 'AttilaMagyar 9/17/2012 20:51'!
command
	^ command! !

!RawLineReceived methodsFor: 'initialize-release' stamp: 'AttilaMagyar 9/17/2012 20:48'!
command: aByteString
	command := aByteString ! !

!RawLineReceived methodsFor: 'initialize-release' stamp: 'AttilaMagyar 9/17/2012 20:51'!
sender
	^ sender! !

!RawLineReceived methodsFor: 'initialize-release' stamp: 'AttilaMagyar 9/17/2012 20:48'!
sender: aByteString 
	sender := aByteString! !

ScrollPane subclass: #IrkaMessagesMorph
	instanceVariableNames: 'messages'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Irka-GUI'!

!IrkaMessagesMorph methodsFor: 'adding' stamp: 'AttilaMagyar 9/24/2012 23:06'!
addMessage: message
	messages add: message! !

!IrkaMessagesMorph methodsFor: 'initialization' stamp: 'AttilaMagyar 9/24/2012 23:44'!
initialize 
	| listBox |
	super initialize.
	messages := IrkaListModel new.
	listBox := (PluggableListMorph 
				on: messages list: #list selected: #index changeSelected: #index: menu: #menu)
				hResizing: #spaceFill; 
				vResizing: #spaceFill;
				yourself.	
	self addMorph: listBox.! !

Object subclass: #Irka
	instanceVariableNames: 'connection translator session'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Irka-Core'!

!Irka class methodsFor: 'instance creation' stamp: 'AttilaMagyar 9/22/2012 18:42'!
host: hostName port: portNumber
	| hostIP |
	hostIP := NetNameResolver addressForName: hostName.
	^ self new ip: hostIP port: portNumber.! !

!Irka methodsFor: 'as yet unclassified' stamp: 'AttilaMagyar 9/23/2012 01:02'!
ip: hostIp port: portNumber
	connection := IrkaConnection to: hostIp port: portNumber.
	session := IrkaSession new.
	translator := IrkaIrcTranslator forConnection: connection.
	session translator: translator.	
	connection announcer on: RawLineReceived send: #translateRaw: to: translator.	
	translator announcer on: IrkaTranslated send: #translated: to: session.		
	[ connection startProcessing ] forkNamed: 'Irka-IRC'.
	^ session.! !

!Irka methodsFor: 'as yet unclassified' stamp: 'AttilaMagyar 9/22/2012 18:40'!
stop
	connection disconnect.! !

Object subclass: #IrkaChannel
	instanceVariableNames: 'users chanName announcer translator'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Irka-Core'!

!IrkaChannel class methodsFor: 'instance creation' stamp: 'AttilaMagyar 9/23/2012 19:01'!
named: chanName translator: anIrkaTranslator
	^ self new chanName: chanName; translator: anIrkaTranslator.! !

!IrkaChannel methodsFor: 'adding' stamp: 'AttilaMagyar 9/15/2012 23:14'!
addUser: aUser
	users add: aUser.! !

!IrkaChannel methodsFor: 'accessing' stamp: 'AttilaMagyar 9/16/2012 12:42'!
announcer 
	^ announcer! !

!IrkaChannel methodsFor: 'accessing' stamp: 'AttilaMagyar 9/15/2012 23:44'!
chanName
	^ chanName! !

!IrkaChannel methodsFor: 'initialize-release' stamp: 'AttilaMagyar 9/15/2012 23:44'!
chanName: aByteSymbol
	chanName := aByteSymbol! !

!IrkaChannel methodsFor: 'initialize-release' stamp: 'AttilaMagyar 9/16/2012 12:45'!
initialize 
	super initialize.
	users := OrderedCollection new.
	announcer := Announcer new.! !

!IrkaChannel methodsFor: 'commands' stamp: 'AttilaMagyar 9/23/2012 19:22'!
leave
	translator translateLeave: chanName.! !

!IrkaChannel methodsFor: 'commands' stamp: 'AttilaMagyar 9/23/2012 19:09'!
message: message
	translator translateMessage: message to: chanName.! !

!IrkaChannel methodsFor: 'events' stamp: 'AttilaMagyar 9/22/2012 23:00'!
message: msg from: user
	announcer announce: (IrkaAction message: msg on: self from: user).! !

!IrkaChannel methodsFor: 'printing' stamp: 'AttilaMagyar 9/24/2012 23:16'!
printString 
	^ chanName ! !

!IrkaChannel methodsFor: 'accessing' stamp: 'AttilaMagyar 9/23/2012 19:01'!
translator: anIrkaTranslator 
	translator := anIrkaTranslator! !

!IrkaChannel methodsFor: 'accessing' stamp: 'AttilaMagyar 9/15/2012 23:59'!
users
	^ users! !

!IrkaChannel methodsFor: 'adding' stamp: 'AttilaMagyar 9/23/2012 00:55'!
users: arrayOfUsers
	users removeAll.
	arrayOfUsers do: [:eachUser | self addUser: eachUser ].! !

Object subclass: #IrkaConnection
	instanceVariableNames: 'sockStream announcer'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Irka-Core'!

!IrkaConnection class methodsFor: 'instance creation' stamp: 'AttilaMagyar 9/22/2012 18:35'!
to: hostIp port: portNumber
	^ self new connectTo: hostIp port: portNumber ! !

!IrkaConnection methodsFor: 'as yet unclassified' stamp: 'AttilaMagyar 9/17/2012 20:34'!
announcer
	^ announcer! !

!IrkaConnection methodsFor: 'as yet unclassified' stamp: 'AttilaMagyar 9/17/2012 20:36'!
chopPrefix: line
	(self hasPrefix: line) 
		ifTrue: [^ line sub] 
		ifFalse: [^line].! !

!IrkaConnection methodsFor: 'as yet unclassified' stamp: 'AttilaMagyar 9/17/2012 20:36'!
connectTo: hostIP port: portNumber
	sockStream := SocketStream openConnectionToHost: hostIP port: portNumber.
	sockStream noTimeout.! !

!IrkaConnection methodsFor: 'as yet unclassified' stamp: 'AttilaMagyar 9/17/2012 20:32'!
disconnect
	sockStream close
! !

!IrkaConnection methodsFor: 'as yet unclassified' stamp: 'AttilaMagyar 9/17/2012 20:41'!
hasPrefix: line
	^ (line size > 0) & ((line at: 1) == $:)! !

!IrkaConnection methodsFor: 'as yet unclassified' stamp: 'AttilaMagyar 9/17/2012 20:34'!
initialize 
	super initialize.
	announcer := Announcer new.! !

!IrkaConnection methodsFor: 'as yet unclassified' stamp: 'AttilaMagyar 9/17/2012 20:49'!
process: line
	| tokens |
	(self hasPrefix: line)
		ifTrue: [ 
			announcer announce: (RawLineReceived parse: line) ]
		ifFalse: [ 
			(line findString: 'PING') == 1
				ifTrue: [ self send: (line copyReplaceAll: 'PING' with: 'PONG') ] ]! !

!IrkaConnection methodsFor: 'as yet unclassified' stamp: 'AttilaMagyar 9/17/2012 20:32'!
send: command
	sockStream sendCommand: command! !

!IrkaConnection methodsFor: 'as yet unclassified' stamp: 'AttilaMagyar 9/17/2012 20:31'!
startProcessing
	| line |	
	[ sockStream isConnected ]
		whileTrue: [
			line := sockStream nextLine.
			self process: line.
			Transcript show: line; cr ]
	! !

Object subclass: #IrkaIrcTranslator
	instanceVariableNames: 'connection announcer'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Irka-Core'!

!IrkaIrcTranslator class methodsFor: 'instance creation' stamp: 'AttilaMagyar 9/22/2012 18:36'!
forConnection: anIrkaConnection
	^ self new connection: anIrkaConnection.! !

!IrkaIrcTranslator methodsFor: 'accessing' stamp: 'AttilaMagyar 9/17/2012 21:08'!
announcer 
	^ announcer ! !

!IrkaIrcTranslator methodsFor: 'parsing' stamp: 'AttilaMagyar 9/24/2012 23:12'!
cmd353: rawLineReceived
	"pharobot4 = #takarodjki :pharobot4 kalohu giszo zeroflag"
	"TODO if chan is empty"
	| parts chan nicks sep |
	sep := (rawLineReceived args includesSubString: ' = ') ifTrue: [ '=' ] ifFalse: [ '@' ].
	parts := (rawLineReceived args findTokens: sep) second trimBoth.
	chan := (parts findTokens: ':') first trimBoth.
	nicks := (parts findTokens: ':') second trimBoth.
	announcer announce: (IrkaTranslated nickList: (nicks findTokens: ' ') asArray on: chan).! !

!IrkaIrcTranslator methodsFor: 'parsing' stamp: 'AttilaMagyar 9/23/2012 00:02'!
cmdJOIN: rawLineReceived
	"command=JOIN args=:#funcoder2"
	| chan user |
	chan := rawLineReceived args.
	user := rawLineReceived sender.
	announcer announce: (IrkaTranslated joined: user to: chan).! !

!IrkaIrcTranslator methodsFor: 'parsing' stamp: 'AttilaMagyar 9/23/2012 00:02'!
cmdPRIVMSG: rawLineReceived
	"command=PRIVMSG args=#funcoder :1 2 3"
	| parts chan msg |
	parts := rawLineReceived args findTokens: ' '.
	chan := parts removeFirst.
	msg := (' ' join: parts) allButFirst: 1.
	announcer announce: (IrkaTranslated message: msg fromNick: rawLineReceived sender toChan: chan).! !

!IrkaIrcTranslator methodsFor: 'initialize-release' stamp: 'AttilaMagyar 9/17/2012 20:19'!
connection: anIrkaConnection 
	connection := anIrkaConnection! !

!IrkaIrcTranslator methodsFor: 'initialize-release' stamp: 'AttilaMagyar 9/17/2012 21:07'!
initialize 
	super initialize.
	announcer := Announcer new.! !

!IrkaIrcTranslator methodsFor: 'translating message to irc' stamp: 'AttilaMagyar 9/22/2012 19:09'!
translateJoin: chanName
	connection send: 'JOIN ', chanName! !

!IrkaIrcTranslator methodsFor: 'as yet unclassified' stamp: 'AttilaMagyar 9/23/2012 19:25'!
translateLeave: chanName 
	connection send: 'PART ', chanName.! !

!IrkaIrcTranslator methodsFor: 'translating message to irc' stamp: 'AttilaMagyar 9/23/2012 19:08'!
translateMessage: message to: target
	connection send: 'PRIVMSG ', target asString, ' :', message asString.! !

!IrkaIrcTranslator methodsFor: 'translating message to irc' stamp: 'AttilaMagyar 9/23/2012 18:48'!
translateQuit
	connection send: 'QUIT'; disconnect.! !

!IrkaIrcTranslator methodsFor: 'translating irc to message' stamp: 'AttilaMagyar 9/23/2012 00:02'!
translateRaw: aRawLineReceived	
	| msg |
	msg := ('cmd', aRawLineReceived command, ':') asSymbol.
	(self respondsTo: msg) ifTrue: [
		self perform: msg with: aRawLineReceived.
	]! !

!IrkaIrcTranslator methodsFor: 'translating message to irc' stamp: 'AttilaMagyar 9/17/2012 20:27'!
translateRegisterUser: aNick
	connection send: 'NICK ', aNick;
					send: 'USER ', aNick, ' Server 0 :', aNick.! !

Object subclass: #IrkaListModel
	instanceVariableNames: 'list index'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Irka-GUI'!

!IrkaListModel methodsFor: 'accessing' stamp: 'AttilaMagyar 9/23/2012 20:55'!
add: element
	list add: element.
	self changed: #list.! !

!IrkaListModel methodsFor: 'accessing' stamp: 'AttilaMagyar 9/23/2012 21:17'!
clean
	list removeAll.
	self changed: #list.! !

!IrkaListModel methodsFor: 'accessing' stamp: 'AttilaMagyar 9/23/2012 20:30'!
index
	^ index! !

!IrkaListModel methodsFor: 'accessing' stamp: 'AttilaMagyar 9/23/2012 20:36'!
index: anInteger
	index := anInteger.
	self changed: #index.! !

!IrkaListModel methodsFor: 'initialization' stamp: 'AttilaMagyar 9/23/2012 20:33'!
initialize 
	super initialize.
	index := 0.
	list := OrderedCollection new.! !

!IrkaListModel methodsFor: 'accessing' stamp: 'AttilaMagyar 9/23/2012 20:30'!
list
	^ list! !

!IrkaListModel methodsFor: 'accessing' stamp: 'AttilaMagyar 9/23/2012 20:32'!
menu
	^ nil! !

Object subclass: #IrkaSession
	instanceVariableNames: 'translator channels nick announcer'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Irka-Core'!

!IrkaSession class methodsFor: 'instance creation' stamp: 'AttilaMagyar 9/17/2012 20:12'!
forUser: nick
	^ self new nick: nick! !

!IrkaSession methodsFor: 'accessing' stamp: 'AttilaMagyar 9/22/2012 19:31'!
announcer 
	^ announcer ! !

!IrkaSession methodsFor: 'translated events' stamp: 'AttilaMagyar 9/24/2012 23:23'!
chanMessageReceived: anIrkaTranslatedChanMsg
	| chan chanName |
	chanName := anIrkaTranslatedChanMsg chanName.
	chan := channels at: chanName ifAbsent: [ ^ nil. "Error signal: 'Chan not found ', chanName" ].	 "TODO priv msg"
	chan message: anIrkaTranslatedChanMsg message from: anIrkaTranslatedChanMsg nick.! !

!IrkaSession methodsFor: 'commands' stamp: 'AttilaMagyar 9/23/2012 18:50'!
changeNick: newNick 
	translator translateChangeNick: newNick.! !

!IrkaSession methodsFor: 'initialize-release' stamp: 'AttilaMagyar 9/22/2012 19:31'!
initialize 
	super initialize.
	channels := Dictionary new.
	announcer := Announcer new.
	nick := 'IrkaSessionNick'.! !

!IrkaSession methodsFor: 'commands' stamp: 'AttilaMagyar 9/22/2012 20:21'!
joinChan: chanName 
	translator translateJoin: chanName asString.! !

!IrkaSession methodsFor: 'translated events' stamp: 'AttilaMagyar 9/23/2012 19:10'!
joined: anIrkaTranslatedJoin
	| chan chanName |	
	chanName := anIrkaTranslatedJoin chanName.
	chan := channels at: chanName ifAbsent: [ IrkaChannel named: chanName translator: translator ].
	chan addUser: anIrkaTranslatedJoin nick.
	channels at: chanName put: chan.
	announcer announce: (IrkaJoined user: anIrkaTranslatedJoin nick to: chan).! !

!IrkaSession methodsFor: 'initialize-release' stamp: 'AttilaMagyar 9/17/2012 20:13'!
nick: aNick
	nick := aNick 
	! !

!IrkaSession methodsFor: 'translated events' stamp: 'AttilaMagyar 9/23/2012 00:54'!
nickListReceived: arrayOfNicks on: chanName
	| chan |
	chan := channels at: chanName ifAbsent: [ Error signal: 'Chan not found ', chanName ].	
	chan users: arrayOfNicks.
	! !

!IrkaSession methodsFor: 'commands' stamp: 'AttilaMagyar 9/23/2012 18:46'!
quit
	translator translateQuit.! !

!IrkaSession methodsFor: 'commands' stamp: 'AttilaMagyar 9/17/2012 20:14'!
register
	translator translateRegisterUser: nick.! !

!IrkaSession methodsFor: 'translated events' stamp: 'AttilaMagyar 9/22/2012 22:49'!
translated: anIrkaTranslated
	anIrkaTranslated whatHappened: self.! !

!IrkaSession methodsFor: 'initialize-release' stamp: 'AttilaMagyar 9/15/2012 22:40'!
translator: anIrkaTranslator
	translator := anIrkaTranslator.! !
